translation_tc = {
    "Add Bible Tab": "新聖經標籤頁",
    "Add Parallel Tab": "新平行標籤頁",
    "Add Tool Tab": "新工具標籤頁",
    "Agent": "代理",
    "AI Chat": "對話模式",
    "AI Commentary": "AI 註釋",
    "Ask BibleMate": "問 BibleMate",
    "Bible Audio": "聖經語音",
    "Bible Chronology": "聖經時序",
    "Bible Commentaries": "聖經註釋",
    "Bible Only": "只顯示聖經",
    "Bible Parallels": "平行經文",
    "Bible Podcast": "聖經廣播",
    "Bible Promises": "聖經應許",
    "Bible": "聖經",
    "Bibles": "聖經",
    "Parallel Bibles": "平行聖經",
    "Timelines": "聖經時間軸",
    "Bible Timelines": "聖經時間軸",
    "Characters": "聖經人物",
    "Close Bible Tab": "關閉聖經標籤頁",
    "Close Others": "關閉其他",
    "Close Parallel Tab": "關閉平行標籤頁",
    "Close Tool Tab": "關閉工具標籤頁",
    "Commentaries": "聖經註釋",
    "Comparison": "版本對比",
    "Copy": "複製",
    "Cross-references": "經文串珠",
    "Dictionaries": "聖經字典",
    "Discourse Analysis": "語法分析",
    "Encyclopedias": "百科全書",
    "Go": "開啓",
    "Indexes": "資源索引",
    "Chapter Indexes": "全章索引",
    "Verse Indexes": "單節索引",
    "Lexicons": "原文詞典",
    "Locations": "聖經地點",
    "Maps": "聖經地圖",
    "Morphological Data": "形態學數據",
    "Morphology": "形態學分析",
    "Names": "聖經名字",
    "Parallels": "平行經文",
    "Partner Mode": "搭檔模式",
    "Preferences": "偏好設定",
    "Promises": "聖經應許",
    "Relationships": "人物關係",
    "Screen": "全螢幕",
    "Fullscreen": "全螢幕",
    "Swap": "版面轉換",
    "Sync": "同步",
    "Tool Only": "只顯示工具",
    "Topics": "聖經主題",
    "Treasury": "經文寶庫",
    "Treasury of Scripture Knowledge": "經文寶庫",
    "Bible & Tool": "聖經與工具",
    "Light Mode": "淺色模式",
    "Dark Mode": "深色模式",
    "Verses": "搜索經文",
    "Tools": "工具",
    "Search": "搜索",
    "Quick search": "快速搜索",
    "AI": "人工智能",
    "Settings": "設定",
    "Swap Layout": "版面轉換",
    "Select Bible Verse": "聖經選單",
    "Toggle Display of Swap Layout Button": "[開啓/關閉] 版面轉換按鈕",
    "Toggle Display of Bible Selection Button": "[開啓/關閉] 聖經選單按鈕",
    "Toggle Bible Synchronization": "[開啓/關閉] 聖經同步功能",
    "Toggle Fullscreen": "[開啓/關閉] 全螢幕",
    "Prev Chapter": "上一章",
    "Next Chapter": "下一章",
    "OT": "舊約",
    "NT": "新約",
    "Select Book": "選擇書卷",
    "Select Chapter": "選擇章數",
    "Select Verse": "選擇節數",
    "Back": "返回",
    "Share": "分享",
    "Note": "筆記",
    "Notes": "筆記",
    "Bible Notes": "聖經筆記",
    "Notepad": "筆記本",
    "Add Note": "新增筆記",
    "Edit Note": "編輯筆記",
    "Save": "儲存",
    "Download": "下載",
    "Import": "匯入",
    "Delete": "刪除",
    "Logout": "登出",
    "Read": "閱讀",
    "Edit": "編輯",
    "Edit Request": "編輯需求",
    "Edit Plan": "編輯計劃",
    "Edit Tools": "編輯工具",
    "Edit Conversation": "編輯對話",
    "Edit Rounds": "編輯回合",
    "Trim Rounds": "修剪回合",
    "Trim Rounds from:": "從下面選擇的回合開始修剪：",
    "Clear": "清除",
    "Download Index": "下載索引",
    "Rebuild Index": "重建索引",
    "Download All": "下載所有筆記",
    "Book Note": "書卷筆記",
    "Chapter Note": "全章筆記",
    "Verse Note": "經文筆記",
    "Book Tools": "書卷工具",
    "Chapter Tools": "全章工具",
    "Verse Tools": "單節工具",
    "Chapter Summary": "全章摘要",
    "Commentary": "經文註釋",
    "Book Analysis": "書卷分析",
    "Overview": "概述",
    "Structural Outline": "結構大綱",
    "Logical Flow": "書卷脈絡",
    "Historical Setting": "歷史背景",
    "Themes": "主題",
    "Keywords": "關鍵詞",
    "Theology": "神學",
    "Canonical Placement": "正典位置",
    "Practical Living": "生活應用",
    "Summary": "摘要",
    "Chapter Map": "全章地圖",
    "Loop": "循環",
    "Edit Mode": "編輯模式",
    "Read Mode": "閱讀模式",
    "Literal": "字面",
    "Regex": "模式",
    "Semantic": "語義",
    "Case-sensitive": "大小寫",
    "Type to filter": "輸入以篩選",
    "results": "結果",
    "result": "結果",
    "Search for words or refs": "搜索經文或參照（如：申 6:4; 約 3:16-18）",
    "Search Bible dictionaries": "搜索聖經字典",
    "Search for a bible topic": "搜索聖經主題",
    "Search for bible promises": "搜索聖經應許",
    "Search for parallel passages": "搜索平行經文",
    "Search for a name or meaning": "搜索名字或含義",
    "Search for location(s) or verse reference(s)": "搜索地點或經文參照",
    "Search for a bible location": "搜索聖經地點",
    "Search for a bible character": "搜索聖經人物",
    "Show Verses": "顯示所有經文",
    "Distance": "距離",
    "From": "從",
    "To": "到",
    "km": "公里",
    "miles": "英里",
    "Loading...": "載入中...",
    "Connecting...": "連線中...",
    "Canceling...": "取消中...",
    "Running...": "執行中...",
    "Stopping...": "停止中...",
    "Stop running task?": "停止執行中的工作？",
    "Enter bible verse reference(s) here...": "在此輸入經文參照...",
    "Start typing your notes here...": "在此開始輸入您的筆記...",
    "Reset All Preferences": "重置所有偏好設定",
    "Language": "語言",
    "Delete": "刪除",
    "Cancel": "取消",
    "Resume": "繼續",
    "Reset": "重置",
    "Confirm": "確認",
    "Partner Mode Review": "夥伴模式審查",
    "Cancelled!": "已取消！",
    "Done!": "完成！",
    "Stop": "停止",
    "Start": "開始",
    "Send": "發送",
    "Auto-scroll": "自動滾動",
    "Scroll to the end automatically": "自動滾動至結尾",
    "Improve Prompt": "優化指示",
    "Enhance": "優化指示",
    "Enhanced Prompt": "經優化的指示",
    "Tools": "工具",
    "Tool Selection": "選用工具",
    "Semantic Searches": "語義搜索",
    "Frequently Used Resources": "常用資源",
    "User & Custom Data": "用戶與自定數據",
    "Tabs Management": "標籤頁管理",
    "Study Plan": "研讀計劃",
    "Prompt Engineering": "優化用戶要求",
    "Tool Instruction": "工具指示",
    "Agent": "代理",
    "Create agents to improve responses": "創建代理優化回應",
    "Use tools to improve responses": "使用工具優化回應",
    "Tool Selection": "選用工具",
    "Final Report": "總結報告",
    "Download the Final Report Only": "只下載總結報告",
    "Download the whole Conversation": "下載完整對話",
    "Downloaded!": "已下載！",
    "Checking daily limit...": "檢查每日限額...",
    "Saving access note...": "記錄使用日期中...",
    "Wrapping up...": "結尾中...",
    "Round": "回合",
    "Appearance": "外觀",
    "Creating agent...": "創建代理中...",
    "Created!": "已創建！",
    "Error": "錯誤",
    "welcome_agent_mode": """**你好！我是 BibleMate AI。** 你已開啟「代理模式 (Agent Mode)」功能。

我能協助你深入查考聖經的內容，包括制定結構化的研經計畫，並跨多種聖經工具執行複雜的多步驟任務。無論是主題式搜尋還是深入的經文分析，我都隨時為你提供協助。

今天你想研習什麼呢？請在下方輸入你的需求以開始執行。

---

💡 提示： 勾選「優化」框，系統將自動完善並釐清你的需求，以獲得更理想的結果。

---""",
    "welcome_chat_mode": """**你好！我是 BibleMate AI。**你已開啟「對話模式 (Chat Mode)」功能。

讓我們一起討論聖經中的任何事物吧！無論你對經文有疑問、需要了解歷史背景，還是想探討特定主題，我隨時都能與你交流。

今天你想討論什麼呢？請在下方輸入你的訊息以開始對話。

---

💡 提示 — 選用功能：

* 優化 (Enhance)： 勾選此項以自動完善並釐清你的提問。
* 代理 (Agent)： 勾選此項以啟動進階邏輯，獲取更詳盡的回答。
* 工具 (Tools)： 勾選此項讓我調用專屬的研經工具組，以確保回覆更加精確。

---""",
    "welcome_partner_mode": """**你好！我是 BibleMate AI。你已開啟「夥伴模式 (Partner Mode)」功能。

在此模式下，我們將作為團隊協作。與代理模式一樣，我會處理複雜的多步驟研經任務，但你始終擁有主導權。你可以審查並調整總體規劃、核准工具選擇，並修改我執行每一步時的指令。

今天想一起研讀什麼呢？請在下方輸入你的需求，開始我們的協作。

---

💡 提示： 勾選「最佳化」框，系統將自動完善並明確你的需求，以獲得更理想的結果。

---""",
    "Agent Mode": "代理模式",
    "Partner Mode": "夥伴模式",
    "Chat Mode": "對話模式",
    "Other AI Modes": "其他模式",
    "Enter your request here...": "在此輸入你的需求",
}