TOOL_DESCRIPTIONS = ('# TOOL DESCRIPTION: `get_direct_text_response`\n'
 'Get a static text-based response directly from a text-based AI model without '
 'using any other tools. This is useful when you want to provide a simple and '
 'direct answer to a question or request, without the need for online latest '
 'updates or task execution.# TOOL DESCRIPTION: `anyalyze_psalms`\n'
 'analyze the context and background of the Psalms in the bible; Psalm '
 'reference must be given, e.g. Psalm 23:1-3\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `ask_bible_scholar`\n'
 'ask a bible scholar about the bible\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `ask_pastor`\n'
 'ask a church pastor about the bible\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `ask_theologian`\n'
 'ask a theologian about the bible\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `compare_bible_translations`\n'
 'compare Bible translations; bible verse reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `explain_bible_meaning`\n'
 'Explain the meaning of the user-given content in reference to the Bible\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `expound_bible_topic`\n'
 'Expound the user-given topic in reference to the Bible; a topic must be '
 'given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `identify_bible_keywords`\n'
 'Identify bible key words from the user-given content\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `interpret_new_testament_verse`\n'
 'Interpret the user-given bible verse from the New Testament in the light of '
 'its context, together with insights of biblical Greek studies; a new '
 'testament bible verse / reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `interpret_old_testament_verse`\n'
 'Interpret the user-given bible verse from the Old Testament in the light of '
 'its context, together with insights of biblical Hebrew studies; an old '
 'testament bible verse / reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `quote_bible_promises`\n'
 'Quote relevant Bible promises in response to user request\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `quote_bible_verses`\n'
 'quote multiple bible verses in response to user request\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `read_bible_commentary`\n'
 'read bible commentary on individual bible verses; bible verse reference(s) '
 'must be given, like , like John 3:16 or John 3:16-18\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `refine_bible_translation`\n'
 'refine the translation of a Bible verse or passage\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `retrieve_bible_chapter`\n'
 'retrieve a whole Bible chapter; bible chapter reference must be given, e.g. '
 'John 3\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `retrieve_bible_cross_references`\n'
 'retrieve cross-references of Bible verses; bible verse reference(s) must be '
 'given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `retrieve_bible_verses`\n'
 'retrieve Bible verses; bible verse reference(s) must be given, e.g. John '
 '3:16-17; single or multiple references accepted, e.g. Deut 6:4; Gen 1:26-27\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `retrieve_hebrew_or_greek_bible_verses`\n'
 'retrieve Hebrew or Greek Bible verses; bible verse reference(s) must be '
 'given, e.g. John 3:16-17; single or multiple references accepted, e.g. Deut '
 '6:4; Gen 1:26-27\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `retrieve_interlinear_hebrew_or_greek_bible_verses`\n'
 'retrieve interlinear Hebrew-English or Greek-English Bible verses; bible '
 'verse reference(s) must be given, e.g. John 3:16-17; single or multiple '
 'references accepted, e.g. Deut 6:4; Gen 1:26-27\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `retrieve_verse_morphology`\n'
 'retrieve parsing and morphology of individual bible verses; bible verse '
 'reference(s) must be given, e.g. John 3:16-17; single or multiple references '
 'accepted, e.g. Deut 6:4; Gen 1:26-27\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_1_chronicles_only`\n'
 'search the book of 1 Chronicles only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_1_corinthians_only`\n'
 'search the book of 1 Corinthians only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_1_john_only`\n'
 'search the book of 1 John only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_1_kings_only`\n'
 'search the book of 1 Kings only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_1_peter_only`\n'
 'search the book of 1 Peter only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_1_samuel_only`\n'
 'search the book of 1 Samuel only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_1_thessalonians_only`\n'
 'search the book of 1 Thessalonians only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_1_timothy_only`\n'
 'search the book of 1 Timothy only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_2_chronicles_only`\n'
 'search the book of 2 Chronicles only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_2_corinthians_only`\n'
 'search the book of 2 Corinthians only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_2_john_only`\n'
 'search the book of 2 John only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_2_kings_only`\n'
 'search the book of 2 Kings only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_2_peter_only`\n'
 'search the book of 2 Peter only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_2_samuel_only`\n'
 'search the book of 2 Samuel only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_2_thessalonians_only`\n'
 'search the book of 2 Thessalonians only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_2_timothy_only`\n'
 'search the book of 2 Timothy only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_3_john_only`\n'
 'search the book of 3 John only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_acts_only`\n'
 'search the book of Acts only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_amos_only`\n'
 'search the book of Amos only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_colossians_only`\n'
 'search the book of Colossians only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_daniel_only`\n'
 'search the book of Daniel only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_deuteronomy_only`\n'
 'search the book of Deuteronomy only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_ecclesiastes_only`\n'
 'search the book of Ecclesiastes only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_ephesians_only`\n'
 'search the book of Ephesians only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_esther_only`\n'
 'search the book of Esther only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_exodus_only`\n'
 'search the book of Exodus only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_ezekiel_only`\n'
 'search the book of Ezekiel only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_ezra_only`\n'
 'search the book of Ezra only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_galatians_only`\n'
 'search the book of Galatians only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_genesis_only`\n'
 'search the book of Genesis only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_habakkuk_only`\n'
 'search the book of Habakkuk only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_haggai_only`\n'
 'search the book of Haggai only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_hebrews_only`\n'
 'search the book of Hebrews only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_hosea_only`\n'
 'search the book of Hosea only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_isaiah_only`\n'
 'search the book of Isaiah only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_james_only`\n'
 'search the book of James only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_jeremiah_only`\n'
 'search the book of Jeremiah only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_job_only`\n'
 'search the book of Job only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_joel_only`\n'
 'search the book of Joel only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_john_only`\n'
 'search the book of John only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_jonah_only`\n'
 'search the book of Jonah only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_joshua_only`\n'
 'search the book of Joshua only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_jude_only`\n'
 'search the book of Jude only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_judges_only`\n'
 'search the book of Judges only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_lamentations_only`\n'
 'search the book of Lamentations only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_leviticus_only`\n'
 'search the book of Leviticus only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_luke_only`\n'
 'search the book of Luke only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_malachi_only`\n'
 'search the book of Malachi only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_mark_only`\n'
 'search the book of Mark only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_matthew_only`\n'
 'search the book of Matthew only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_micah_only`\n'
 'search the book of Micah only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_nahum_only`\n'
 'search the book of Nahum only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_nehemiah_only`\n'
 'search the book of Nehemiah only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_numbers_only`\n'
 'search the book of Numbers only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_obadiah_only`\n'
 'search the book of Obadiah only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_philemon_only`\n'
 'search the book of Philemon only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_philippians_only`\n'
 'search the book of Philippians only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_proverbs_only`\n'
 'search the book of Proverbs only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_psalms_only`\n'
 'search the book of Psalms only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_revelation_only`\n'
 'search the book of Revelation only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_romans_only`\n'
 'search the book of Romans only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_ruth_only`\n'
 'search the book of Ruth only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_song_of_songs_only`\n'
 'search the book of Song of Songs only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_the_whole_bible`\n'
 'search the whole bible; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_titus_only`\n'
 'search the book of Titus only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_zechariah_only`\n'
 'search the book of Zechariah only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `search_zephaniah_only`\n'
 'search the book of Zephaniah only; search string must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `study_bible_themes`\n'
 'Study Bible Themes in relation to the user content\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `study_new_testament_themes`\n'
 'Study Bible Themes in a New Testament passage; new testament bible book / '
 'chapter / passage / reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `study_old_testament_themes`\n'
 'Study Bible Themes in a Old Testament passage; old testatment bible book / '
 'chapter / passage / reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `translate_greek_bible_verse`\n'
 'Translate a Greek bible verse: Greek bible text must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `translate_hebrew_bible_verse`\n'
 'Translate a Hebrew bible verse; Hebrew bible text must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_bible_applications`\n'
 'Provide detailed applications of a bible passages; bible book / chapter / '
 'passage / reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_bible_book_introduction`\n'
 'Write a detailed introduction on a book in the bible; bible book must be '
 'given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_bible_canonical_context`\n'
 'Write about canonical context of a bible book / chapter / passage; bible '
 'book / chapter / passage / reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_bible_chapter_summary`\n'
 'Write a detailed interpretation on a bible chapter; a bible chapter must be '
 'given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_bible_character_study`\n'
 'Write comprehensive information on a given bible character in the bible; a '
 'bible character name must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_bible_devotion`\n'
 'Write a devotion on a bible passage; bible book / chapter / passage / '
 'reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_bible_insights`\n'
 'Write exegetical insights in detail on a bible passage; bible book / chapter '
 '/ passage / reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_bible_location_study`\n'
 'write comprehensive information on a bible location; a bible location name '
 'must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_bible_outline`\n'
 'provide a detailed outline of a bible book / chapter / passage; bible book / '
 'chapter / passage / reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_bible_perspectives`\n'
 'Write biblical perspectives and principles in relation to the user content\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_bible_prayer`\n'
 'Write a prayer pertaining to the user content in reference to the Bible\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_bible_questions`\n'
 'Write thought-provoking questions for bible study group discussion; bible '
 'book / chapter / passage / reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_bible_related_summary`\n'
 'Write a summary on the user-given content in reference to the Bible\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_bible_sermon`\n'
 'Write a bible sermon based on a bible passage; bible book / chapter / '
 'passage / reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_bible_theology`\n'
 'write the theological messages conveyed in the user-given content, in '
 'reference to the Bible\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_bible_thought_progression`\n'
 'write Bible Thought Progression of a bible book / chapter / passage; bible '
 'book / chapter / passage / reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_new_testament_highlights`\n'
 'Write Highlights in a New Testament passage in the bible; new testament '
 'bible book / chapter / passage / reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_new_testament_historical_context`\n'
 'write the Bible Historical Context of a New Testament passage in the bible; '
 'new testament bible book / chapter / passage / reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_old_testament_highlights`\n'
 'Write Highlights in a Old Testament passage in the bible; old testament '
 'bible book / chapter / passage / reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_old_testament_historical_context`\n'
 'write the Bible Historical Context of a Old Testament passage in the bible; '
 'old testament bible book / chapter / passage / reference(s) must be given\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_pastor_prayer`\n'
 'write a prayer, out of a church pastor heart, based on user input\n'
 '\n'
 '\n'
 '# TOOL DESCRIPTION: `write_short_bible_prayer`\n'
 'Write a short prayer, in one paragraph only, pertaining to the user content '
 'in reference to the Bible\n'
 '\n'
 '\n')